==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ScatterAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColorScaleDescriptionMetadata } from "./ColorScaleDescriptionMetadata";
import { ScatterTriangulationSeriesDescriptionMetadata } from "./ScatterTriangulationSeriesDescriptionMetadata";
import { ScatterAreaSeriesDescription } from "./ScatterAreaSeriesDescription";
/**
 * @hidden
 */
export let ScatterAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterAreaSeriesDescriptionMetadata.a == null) {
                ScatterAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterAreaSeriesDescriptionMetadata.c(ScatterAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(ScatterAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(ScatterAreaSeriesDescriptionMetadata.a);
            ColorScaleDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterTriangulationSeriesDescriptionMetadata.c(a);
            a.item("ColorScale", "ExportedType:ColorScale");
            a.item("ColorMemberPath", "String");
            a.item("ActualColorScale", "ExportedType:ColorScale");
            a.item("ColorMemberAsLegendLabel", "String");
            a.item("ColorMemberAsLegendUnit", "String");
        }
        static d(a) {
            ScatterAreaSeriesDescriptionMetadata.b(a);
            a.aa("ScatterAreaSeries", () => new ScatterAreaSeriesDescription());
            a.z("ScatterAreaSeries", ScatterAreaSeriesDescriptionMetadata.a);
        }
    }
    ScatterAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterAreaSeriesDescriptionMetadata, 'ScatterAreaSeriesDescriptionMetadata');
    ScatterAreaSeriesDescriptionMetadata.a = null;
    return ScatterAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ScatterAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColorScaleDescriptionMetadata } from "./ColorScaleDescriptionMetadata";
import { ScatterTriangulationSeriesDescriptionMetadata } from "./ScatterTriangulationSeriesDescriptionMetadata";
import { ScatterAreaSeriesDescription } from "./ScatterAreaSeriesDescription";
/**
 * @hidden
 */
export let ScatterAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterAreaSeriesDescriptionMetadata.a == null) {
                ScatterAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterAreaSeriesDescriptionMetadata.c(ScatterAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(ScatterAreaSeriesDescriptionMetadata.a);
            ColorScaleDescriptionMetadata.d(a);
        }
        static c(a) {
            ScatterTriangulationSeriesDescriptionMetadata.c(a);
            a.item("ColorScale", "ExportedType:ColorScale");
            a.item("ColorMemberPath", "String");
            a.item("ActualColorScale", "ExportedType:ColorScale");
            a.item("ColorMemberAsLegendLabel", "String");
            a.item("ColorMemberAsLegendUnit", "String");
        }
        static d(a) {
            ScatterAreaSeriesDescriptionMetadata.b(a);
            a.ac("ScatterAreaSeries", () => new ScatterAreaSeriesDescription());
            a.ab("ScatterAreaSeries", ScatterAreaSeriesDescriptionMetadata.a);
        }
    }
    ScatterAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterAreaSeriesDescriptionMetadata, 'ScatterAreaSeriesDescriptionMetadata');
    ScatterAreaSeriesDescriptionMetadata.a = null;
    return ScatterAreaSeriesDescriptionMetadata;
})();
